summaryrefslogtreecommitdiffstats
path: root/cpukit/score/include/rtems/score/object.h
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2008-01-31 14:14:27 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2008-01-31 14:14:27 +0000
commit91b8fb9e9aae067834e702370b311c69a05e1df9 (patch)
tree09388c57f8f0e6020c97782a9be7078e7fc6869a /cpukit/score/include/rtems/score/object.h
parent2008-01-30 Joel Sherrill <joel.sherrill@OARcorp.com> (diff)
downloadrtems-91b8fb9e9aae067834e702370b311c69a05e1df9.tar.bz2
2008-01-31 Joel Sherrill <joel.sherrill@OARcorp.com>
* score/include/rtems/score/object.h, score/src/objectgetinfo.c, rtems/include/rtems/rtems/object.h, rtems/src/rtemsobjectgetapiclassname.c, rtems/src/rtemsobjectgetclassinfo.c: class is a C++ keyword and cannot be used as a parameter.
Diffstat (limited to 'cpukit/score/include/rtems/score/object.h')
-rw-r--r--cpukit/score/include/rtems/score/object.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/cpukit/score/include/rtems/score/object.h b/cpukit/score/include/rtems/score/object.h
index aa3218adc0..7ea986c6ec 100644
--- a/cpukit/score/include/rtems/score/object.h
+++ b/cpukit/score/include/rtems/score/object.h
@@ -803,15 +803,15 @@ Objects_Control *_Objects_Get_next(
* an the API and Class. This can be done independent of
* the existence of any objects created by the API.
*
* @param[in] api indicates the API for the information we want
* @param[in] class indicates the Class for the information we want
*
* @return This method returns a pointer to the Object Information Table
* for the class of objects which corresponds to this object ID.
*/
Objects_Information *_Objects_Get_information(
- Objects_APIs api,
- uint32_t class
+ Objects_APIs the_api,
+ uint32_t the_class
);
/**
@@ -803,15 +803,15 @@ Objects_Control *_Objects_Get_next(
* the existence of any objects created by the API.
*
- * @param[in] api indicates the API for the information we want
- * @param[in] class indicates the Class for the information we want
+ * @param[in] the_api indicates the API for the information we want
+ * @param[in] the_class indicates the Class for the information we want
*
* @return This method returns a pointer to the Object Information Table